Exceptions class

Implemented types
Implementers
Annotations
  • @freezed

Constructors

Exceptions.emailInvalide()
const
factory
Exceptions.invalidCode()
const
factory
Exceptions.invalidConfirmationCode()
const
factory
Exceptions.invalidInput()
const
factory
Exceptions.locationPermissionDenied()
const
factory
Exceptions.locationServiceNotEnabled()
const
factory
Exceptions.network()
const
factory
Exceptions.other()
const
factory
Exceptions.phoneInvalid()
const
factory
Exceptions.unAuthorized()
const
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>({required TResult network(NetworkException value), required TResult other(OtherException value), required TResult locationServiceNotEnabled(LocationServiceNotEnabled value), required TResult locationPermissionDenied(LocationPermissionDeniedException value), required TResult emailInvalide(EmailInvalude value), required TResult invalidCode(InvalidCode value), required TResult phoneInvalid(PhoneInvalid value), required TResult invalidConfirmationCode(InvalidConfirmationCode value), required TResult unAuthorized(_unAuthorized value), required TResult invalidInput(_invalidInput value)}) → TResult
inherited
mapOrNull<TResult extends Object?>({TResult? network(NetworkException value)?, TResult? other(OtherException value)?, TResult? locationServiceNotEnabled(LocationServiceNotEnabled value)?, TResult? locationPermissionDenied(LocationPermissionDeniedException value)?, TResult? emailInvalide(EmailInvalude value)?, TResult? invalidCode(InvalidCode value)?, TResult? phoneInvalid(PhoneInvalid value)?, TResult? invalidConfirmationCode(InvalidConfirmationCode value)?, TResult? unAuthorized(_unAuthorized value)?, TResult? invalidInput(_invalidInput value)?}) → TResult?
inherited
maybeMap<TResult extends Object?>({TResult network(NetworkException value)?, TResult other(OtherException value)?, TResult locationServiceNotEnabled(LocationServiceNotEnabled value)?, TResult locationPermissionDenied(LocationPermissionDeniedException value)?, TResult emailInvalide(EmailInvalude value)?, TResult invalidCode(InvalidCode value)?, TResult phoneInvalid(PhoneInvalid value)?, TResult invalidConfirmationCode(InvalidConfirmationCode value)?, TResult unAuthorized(_unAuthorized value)?, TResult invalidInput(_invalidInput value)?, required TResult orElse()}) → TResult
inherited
maybeWhen<TResult extends Object?>({TResult network()?, TResult other()?, TResult locationServiceNotEnabled()?, TResult locationPermissionDenied()?, TResult emailInvalide()?, TResult invalidCode()?, TResult phoneInvalid()?, TResult invalidConfirmationCode()?, TResult unAuthorized()?, TResult invalidInput()?, required TResult orElse()}) → TResult
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>({required TResult network(), required TResult other(), required TResult locationServiceNotEnabled(), required TResult locationPermissionDenied(), required TResult emailInvalide(), required TResult invalidCode(), required TResult phoneInvalid(), required TResult invalidConfirmationCode(), required TResult unAuthorized(), required TResult invalidInput()}) → TResult
inherited
whenOrNull<TResult extends Object?>({TResult? network()?, TResult? other()?, TResult? locationServiceNotEnabled()?, TResult? locationPermissionDenied()?, TResult? emailInvalide()?, TResult? invalidCode()?, TResult? phoneInvalid()?, TResult? invalidConfirmationCode()?, TResult? unAuthorized()?, TResult? invalidInput()?}) → TResult?
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited